from setuptools import setup

setup(name='v03_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['v03_distributions'],
      author = 'Jhon Nagasako',
      author_email = 'test@test.com',
      zip_safe=False)
